PatchbayBlobMetadataWire class final

Strict wire representation of PatchbayBlobMetadataWire.

Constructors

PatchbayBlobMetadataWire({required String blobId, required PatchbayFactSourceWire source, required PatchbayBlobSourceWire kind, required String contentType, required int length, required String sha256, required String createdAt, required String expiresAt, required String? filename, required Map<String, Object?> properties})
Creates a fully validated wire value.
const
PatchbayBlobMetadataWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

blobId String
Value of the blobId wire field.
final
contentType String
Value of the contentType wire field.
final
createdAt String
Value of the createdAt wire field.
final
expiresAt String
Value of the expiresAt wire field.
final
filename String?
Value of the filename wire field.
final
hashCode int
The hash code for this object.
no setterinherited
kind PatchbayBlobSourceWire
Value of the kind wire field.
final
length int
Value of the length wire field.
final
properties Map<String, Object?>
Value of the properties wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sha256 String
Value of the sha256 wire field.
final
source PatchbayFactSourceWire
Value of the source wire field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited