PatchbayInvocationCancellationSignal class final
Read-only cancellation signal exposed to a context-aware consumer.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRequested → bool
-
no setter
- reason → PatchbayInvocationCancellationReason?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- whenRequested → Duration?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited