PatchbayJobCancellationSignal class final

A consumer-observed domain cancellation whose payload is already redacted.

Implemented types

Constructors

PatchbayJobCancellationSignal({required String reason, Map<String, Object?> payload = const {}})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
payload Map<String, Object?>
final
reason String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited