PatchbayLogLevelWire enum

Strict wire representation of PatchbayLogLevelWire.

Inheritance
Available extensions

Values

trace → const PatchbayLogLevelWire

The trace wire value.

debug → const PatchbayLogLevelWire

The debug wire value.

info → const PatchbayLogLevelWire

The info wire value.

warning → const PatchbayLogLevelWire

The warning wire value.

error → const PatchbayLogLevelWire

The error wire value.

fatal → const PatchbayLogLevelWire

The fatal wire value.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
Encodes this value using its stable wire name.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Object? value, {String path = r'$'}) PatchbayLogLevelWire
Decodes a value at path, rejecting unknown values.

Constants

values → const List<PatchbayLogLevelWire>
A constant List of the values in this enum, in order of their declaration.