PatchbayResponseSchema class final

Accepted and job-terminal payload declarations for one command.

Constructors

PatchbayResponseSchema({required PatchbayResponseValueSchema accepted, Map<String, PatchbayResponseValueSchema> terminal = const {}})
const
PatchbayResponseSchema.fromJson(Object? value)
factory

Properties

accepted PatchbayResponseValueSchema
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminal Map<String, PatchbayResponseValueSchema>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited