PatchbayAuditDrainResult class final

Immutable accounting for the audit events accepted before the drain gate.

Constructors

PatchbayAuditDrainResult({required PatchbayAuditDrainOutcome outcome, required int settledCount, required int overflowDroppedCount, required int abandonedCount})
const

Properties

abandonedCount int
final
hashCode int
The hash code for this object.
no setterinherited
outcome PatchbayAuditDrainOutcome
final
overflowDroppedCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settledCount int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited