gateDisposition property
One of patchbayAuditGateDispositions, or null on a host that predates it.
Implementation
final String? gateDisposition;
One of patchbayAuditGateDispositions, or null on a host that predates it.
final String? gateDisposition;