PatchbayCaptureDiffRequestWire class final

Strict wire representation of PatchbayCaptureDiffRequestWire.

Constructors

PatchbayCaptureDiffRequestWire({required String beforeBlobId, required String afterBlobId})
Creates a fully validated wire value.
const
PatchbayCaptureDiffRequestWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

afterBlobId String
Value of the afterBlobId wire field.
final
beforeBlobId String
Value of the beforeBlobId wire field.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited