PatchbayDecodedCapture class final

Constructors

PatchbayDecodedCapture({required Uint8List bytes, required int width, required int height, required String pixelFormat, required int bytesPerPixel})
const

Properties

bytes Uint8List
final
bytesPerPixel int
final
hashCode int
The hash code for this object.
no setterinherited
height int
final
pixelFormat String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spec Map<String, Object?>
no setter
width int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited