PatchbayExecutionValidationResult class final

Constructors

PatchbayExecutionValidationResult({List<PatchbayResponseValidationIssue> issues = const <PatchbayResponseValidationIssue>[], bool legacyDispatchedConflict = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
issues List<PatchbayResponseValidationIssue>
final
legacyDispatchedConflict bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited