inspect property
Non-null only when the consumer opted into the widget inspector switch.
Implementation
late final PatchbayInspectBridge? inspect;
Non-null only when the consumer opted into the widget inspector switch.
late final PatchbayInspectBridge? inspect;