PatchbayFrameObserver class final

Counts only frames explicitly observed by Patchbay operations.

Constructors

PatchbayFrameObserver()

Properties

hashCode int
The hash code for this object.
no setterinherited
revision int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

framesBefore(DateTime deadline, int count) Future<int>
Requests and observes up to count frames before one shared deadline.
nextFrameBefore(DateTime deadline) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited