PatchbayGestureDecision class final

Consumer decision and optional tighter budgets for one gesture.

Constructors

PatchbayGestureDecision.allow({Set<String> gateIds = const <String>{}, int maxDurationMs = 30000, int maxPathPoints = 64, double maxVelocity = 20})
const
PatchbayGestureDecision.reject({String? rejectionCode = 'uiGestureDenied', String? rejectionNotice})
const

Properties

allowed bool
no setter
gateIds Set<String>
final
hashCode int
The hash code for this object.
no setterinherited
maxDurationMs int
final
maxPathPoints int
final
maxVelocity double
final
rejectionCode String?
final
rejectionNotice String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited