PatchbayGestureKind enum

Pointer gesture families supported by the anchored gesture bridge.

tap 追加在末尾:既有值的 index 不变,穷尽 switch 的接入方会拿到分析器 错误并在编译期对新 kind 做决定(DG-050-08 的 fail-closed 形态)。

Inheritance
Available extensions

Values

pressHold → const PatchbayGestureKind
drag → const PatchbayGestureKind
fling → const PatchbayGestureKind
tap → const PatchbayGestureKind

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PatchbayGestureKind>
A constant List of the values in this enum, in order of their declaration.