PatchbayGestureTarget class final

Read-only target facts supplied to the independent gesture policy.

Constructors

PatchbayGestureTarget({required int nodeId, required int generation, required String identifier, required Set<String> flags})
const

Properties

flags Set<String>
final
generation int
final
hashCode int
The hash code for this object.
no setterinherited
identifier String
final
nodeId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited