PatchbayHostInvocationHandle class final

A response may freeze before the underlying invocation lifecycle releases.

Constructors

PatchbayHostInvocationHandle({required Future<Map<String, Object?>> response, required Future<void> lifecycle})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
lifecycle Future<void>
final
response Future<Map<String, Object?>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited