enabled property
bool
get
enabled
Whether the App is currently asking the host to hold the screen awake.
Implementation
bool get enabled => _enabled;
Whether the App is currently asking the host to hold the screen awake.
bool get enabled => _enabled;