PatchbayNavigationAdapter class final
The single navigation adapter injected at the consumer composition root.
Constructors
-
const
Properties
- back → PatchbayNavigationRequest?
-
final
-
backGateIds
→ Set<
String> -
final
- current → PatchbayNavigationObservationSource
-
final
- destinations → PatchbayNavigationCatalogSource
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited