PatchbaySemanticsAction enum

Stable Patchbay names for the first supported Flutter semantics actions.

Inheritance
Available extensions

Values

tap → const PatchbaySemanticsAction
longPress → const PatchbaySemanticsAction
focus → const PatchbaySemanticsAction
dismiss → const PatchbaySemanticsAction
showOnScreen → const PatchbaySemanticsAction
scrollUp → const PatchbaySemanticsAction
scrollDown → const PatchbaySemanticsAction
scrollLeft → const PatchbaySemanticsAction
scrollRight → const PatchbaySemanticsAction
increase → const PatchbaySemanticsAction
decrease → const PatchbaySemanticsAction
expand → const PatchbaySemanticsAction
collapse → const PatchbaySemanticsAction
setText → const PatchbaySemanticsAction

Properties

flutterAction SemanticsAction
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromWireName(String value) PatchbaySemanticsAction?

Constants

values → const List<PatchbaySemanticsAction>
A constant List of the values in this enum, in order of their declaration.