PatchbaySemanticsIdentifierMatch class final

One currently attached node selected by a stable Semantics identifier.

Constructors

PatchbaySemanticsIdentifierMatch({required int nodeId, required int generation, required String value, required bool obscured, required bool invisible})
const

Properties

generation int
final
hashCode int
The hash code for this object.
no setterinherited
invisible bool
final
nodeId int
final
obscured bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited