PatchbaySemanticsIdentifierObservation class final
Current result of resolving a Semantics identifier.
Constructors
-
PatchbaySemanticsIdentifierObservation({required int treeRevision, required List<
PatchbaySemanticsIdentifierMatch> matches}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
matches
→ List<
PatchbaySemanticsIdentifierMatch> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- treeRevision → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited