PatchbayUiWaitRequest class final

Validated, consumer-neutral request for one bounded Flutter observation.

Constructors

PatchbayUiWaitRequest({required PatchbayUiWaitCondition condition, required Duration timeout, String? semanticsIdentifier, String? value, String? destinationId, int? revision})
PatchbayUiWaitRequest.fromWire(PatchbayUiWaitRequestWire wire)
factory

Properties

condition PatchbayUiWaitCondition
final
destinationId String?
final
hashCode int
The hash code for this object.
no setterinherited
revision int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsIdentifier String?
final
timeout Duration
final
value String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toWire() PatchbayUiWaitRequestWire

Operators

operator ==(Object other) bool
The equality operator.
inherited