PatchbayUiWaitRequestWire class final

Strict wire representation of PatchbayUiWaitRequestWire.

Constructors

PatchbayUiWaitRequestWire({required PatchbayUiWaitConditionWire condition, required int timeoutMs, required String? semanticsIdentifier, required String? value, required String? destinationId, required int? revision})
Creates a fully validated wire value.
const
PatchbayUiWaitRequestWire.fromJson(Map<String, Object?> json, {String path = r'$'})
Decodes a strict JSON object at path.
factory

Properties

condition PatchbayUiWaitConditionWire
Value of the condition wire field.
final
destinationId String?
Value of the destinationId wire field.
final
hashCode int
The hash code for this object.
no setterinherited
revision int?
Value of the revision wire field.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsIdentifier String?
Value of the semanticsIdentifier wire field.
final
timeoutMs int
Value of the timeoutMs wire field.
final
value String?
Value of the value wire field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this value as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited