PatchbayCommandRegistry class final
Transport-neutral catalog and dispatch table for protocol-owned commands.
Constructors
-
PatchbayCommandRegistry(Iterable<
PatchbayCommandRegistration< registrations)Object?> > -
PatchbayCommandRegistry.combine(Iterable<
PatchbayCommandRegistry> registries) -
factory
Properties
-
descriptors
→ List<
PatchbayCommandDescriptor> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasResponseSchemas → bool
-
no setter
- isEmpty → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispatch(
String command, Map< String, Object?> arguments, String requestId, {PatchbayInvocationContext? context}) → Future<Map< String, Object?> > - Dispatches within this registry and types an unknown command as rejected.
-
executionContractFor(
String command) → PatchbayExecutionContract? -
handles(
String command) → bool -
isContextAware(
String command) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
responseSchemaFor(
String command) → PatchbayResponseSchema? -
toString(
) → String -
A string representation of this object.
inherited
-
tryDispatch(
String command, Map< String, Object?> arguments, String requestId, {void onGateResult(String result)?, PatchbayInvocationContext? context}) → Future<Map< String, Object?> ?> - Dispatches a registered command, or returns null for the external layer.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited