PatchbayDestinationDescriptorWire class final
Strict wire representation of PatchbayDestinationDescriptorWire.
Constructors
-
PatchbayDestinationDescriptorWire({required String id, required String? summary, required List<
PatchbayNavigationOperationWire> operations, required List<String> gates, required bool ambiguous}) -
Creates a fully validated wire value.
const
-
PatchbayDestinationDescriptorWire.fromJson(Map<
String, Object?> json, {String path = r'$'}) -
Decodes a strict JSON object at
path.factory
Properties
- ambiguous → bool
-
Value of the
ambiguouswire field.final -
gates
→ List<
String> -
Value of the
gateswire field.final - hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Value of the
idwire field.final -
operations
→ List<
PatchbayNavigationOperationWire> -
Value of the
operationswire field.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summary → String?
-
Value of the
summarywire field.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this value as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited