PatchbayLogPage class final
Consumer-owned query result. Patchbay applies its own response bounds after the source returns and never subscribes to or takes ownership of the source.
Constructors
-
PatchbayLogPage.records({List<
PatchbayRedactedLogRecord> records = const <PatchbayRedactedLogRecord>[], String? nextCursor, bool sourceTruncated = false}) -
const
- PatchbayLogPage.staleCursor({required String? currentCursor})
-
const
Properties
- currentCursor → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextCursor → String?
-
final
-
records
→ List<
PatchbayRedactedLogRecord> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceTruncated → bool
-
final
- state → PatchbayLogPageState
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited