PatchbayRedactedLogRecord class final
A log record whose public constructor enforces Patchbay's defensive redaction boundary before a consumer source can return it.
Constructors
-
PatchbayRedactedLogRecord({required String cursor, required DateTime at, required PatchbayLogLevelWire level, required String category, required String message, Map<
String, Object?> fields = const <String, Object?>{}})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wire → PatchbayLogRecordWire
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited