PatchbayResponseValueSchema class final
One recursively declared response value.
Constructors
-
PatchbayResponseValueSchema({required PatchbayResponseType type, bool nullable = false, Map<
String, PatchbayResponseValueSchema> properties = const <String, PatchbayResponseValueSchema>{}, Set<String> required = const <String>{}, bool additionalProperties = false, PatchbayResponseValueSchema? items, String? discriminator, Map<String, PatchbayResponseValueSchema> variants = const <String, PatchbayResponseValueSchema>{}, Set<String> allowedValues = const <String>{}}) -
const
- PatchbayResponseValueSchema.fromJson(Object? value)
-
factory
Properties
- additionalProperties → bool
-
final
-
allowedValues
→ Set<
String> -
final
- discriminator → String?
-
Object field selecting one member of variants.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- items → PatchbayResponseValueSchema?
-
final
- nullable → bool
-
final
-
properties
→ Map<
String, PatchbayResponseValueSchema> -
final
-
required
→ Set<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → PatchbayResponseType
-
final
-
variants
→ Map<
String, PatchbayResponseValueSchema> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited