PatchbayFlutterBridge class final
Executes cataloged UI operators after base and descriptor gates.
Constructors
-
PatchbayFlutterBridge({required PatchbayGateEvaluator gates, PatchbayUiRegistry? registry, PatchbaySemanticsActionPolicy? semanticsActionPolicy, PatchbayGesturePolicy? gesturePolicy, PatchbayPointerEventDispatcher? gesturePointerDispatcher, PatchbayGestureDelay? gestureDelay, PatchbayRevealPolicy? revealPolicy, PatchbayInspectPolicy? inspectPolicy, PatchbayInspectorSurface? inspectorSurface, PatchbayArtifactService? artifacts, Set<
String> captureGates = const <String>{}, PatchbayKeepAwakeDelegate? keepAwakeDelegate, Set<String> keepAwakeGates = const <String>{}, PatchbayRootController? rootController, PatchbayCaptureEncoder? captureEncoder, PatchbayCaptureDecoder? captureDecoder, bool isAppResumed()?, PatchbayLifecycleStateReader? lifecycleState, String newRequestId()?})
Properties
- artifacts → PatchbayArtifactService?
-
final
- capture ↔ PatchbayCaptureBridge?
-
latefinal
- frameRevision → int
-
no setter
- gates → PatchbayGateEvaluator
-
The one evaluator every plane of this host shares.
no setter
- gesture ↔ PatchbayGestureBridge
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- inspect ↔ PatchbayInspectBridge?
-
Non-null only when the consumer opted into the widget inspector switch.
latefinal
- keepAwake ↔ PatchbayKeepAwakeBridge
-
Always present, unlike capture and navigation.
latefinal
-
latefinal
- reveal ↔ PatchbayRevealBridge
-
PB-050-17:identifier 锚定的 scroll-to-reveal。
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semantics ↔ PatchbaySemanticsBridge
-
latefinal
- wait ↔ PatchbayUiWaitBridge
-
latefinal
Methods
-
catalog(
) → List< PatchbayUiTargetDescriptor> -
dispose(
) → void -
enterText(
{required String id, required int generation, required String text, bool inputWasStdin = false, String? requestId}) → Future< PatchbayInvocation> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setText(
{required String id, required int generation, required String text, bool inputWasStdin = false, String? requestId}) → Future< PatchbayInvocation> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited