PatchbayNavigationBridge class final

Serial, revision-fenced destination navigation with UI observation.

Constructors

PatchbayNavigationBridge({required PatchbayGateEvaluator gates, required PatchbayNavigationAdapter adapter, required PatchbayFrameObserver frames, required bool isAppResumed(), required PatchbayLifecycleStateReader lifecycleState, String newRequestId()?})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

back({required int revision, required Duration timeout, String? requestId}) Future<PatchbayInvocation>
catalog({String? requestId}) Future<PatchbayInvocation>
current({String? requestId}) Future<PatchbayInvocation>
destinationIsAmbiguous(String id) bool
destinationIsRegistered(String id) bool
go({required String destinationId, required int revision, required Duration timeout, String? requestId}) Future<PatchbayInvocation>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
observeForWait() PatchbayNavigationObservation
push({required String destinationId, required int revision, required Duration timeout, String? requestId}) Future<PatchbayInvocation>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited