PatchbaySemanticsActionDecision class final
Consumer-owned decision for one currently observed semantics action.
Constructors
-
PatchbaySemanticsActionDecision.allow({Set<
String> gateIds = const <String>{}, bool sensitiveInput = false}) -
const
- PatchbaySemanticsActionDecision.reject({String? rejectionCode = 'uiSemanticsActionDenied', String? rejectionNotice})
-
const
Properties
- allowed → bool
-
no setter
-
gateIds
→ Set<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rejectionCode → String?
-
final
- rejectionNotice → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sensitiveInput → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited